<!DOCTYPE TS><TS>
<context>
    <name>PhoneUIBox</name>
    <message>
        <source>Add someone to your Directory </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit this Entry</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove from Speed Dials</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save this in the Directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clear the Call History</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Make this a Speeddial</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete this Entry</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete this Voicemail</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete all Voicemails</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Place Videocall Now</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Place Voice-Only Call Now</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Switch from digits to URL input</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Switch from URL to Digits input</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Send IM</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save Changes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ADD</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ADD DIRECTORY</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Registered to </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> as </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Not Registered</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio and Video Looped to </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No Active Calls</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Caller is Leaving Voicemail</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Trying to Contact Remote Party</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Incoming Call</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hanging Up</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Speed Dials</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Call History</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Voicemail</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Nickname</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>First Name (Optional)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Surname (Optional)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>URL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Speed Dial</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Client is on My Home LAN</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Default Photo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>To Directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Business Card</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Latest Calls:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> Videocall</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> Voice-Only</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Send an Instant Message</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You Called </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>They Called </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You missed their call </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Today </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Yesterday </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>at</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> for %d min</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Packets In/Out/Lost/Late:             </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Resolution In/Out: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Packets In/Lost/Disc/Late: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Packets Out/Dropped: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video Frames In/Out/Disc: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Average FPS In/Out: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Webcam Frames Delivered/Dropped: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Packets In/Out/Lost/Late: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Volume</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mic Volume (not impl.)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio Codec</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Brightness</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Contrast</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Colour</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Transmit Video Size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Transmit Video FPS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Up/Down - Change       Left/Right - Adjust</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Dial</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Playout Delay Min/Avg/Max:            </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Packets Lost by Peer:                 </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Packets Lost by Peer: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Playout Delay Min/Avg/Max: </source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Webcam device</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select the device path your webcam is using. If you have a capture card it may be using /dev/video so try dev/video1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Transmit Resolution</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Size of video window to transmit; higher resolutions require more bandwidth.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Capture Resolution</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Size of video source from your webcam. Choose a value compatible with your webcam hardware. Choose higher values to digitally pan/zoom before transmission.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Transmit Frames/Second</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Time to Answer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The time in seconds a call rings before being automatically answered and diverted to a VXML script.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Default VXML URL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The URL to retrieve a VXML script which can be used to prompt for leaving a voicemail etc. Leave blank if you have no HTTP server and a default Voicemail script will be used.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Default Voicemail Prompt</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>I am not at home, please leave a message after the tone</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Either a text message to be read by the TTS engine or the filename of a .wav file to be played to callers. Only used where the above setting is blank.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Text to Speech Voice</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Choose a voice to use from the Text To Speech library. </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Allows you to register with services such as Free World Dialup; or with applications like Asterisk. Restart mythfrontend if you change this.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Name of the Proxy, such as fwd.pulver.com for Free World Dialup.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SIP Local Port</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The port on this machine to use. You may need to make these different for each Mythfrontend and setup your firewall to let this port through.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Microphone device</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select the device path for your microphone. Currently this CANNOT be the same device as used for audio output.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>My Display Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>My common name to display when I call other people. </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Codecs Supported</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The list of codecs to use, in the preferred order separated by semicolon. Supported codecs are G.711u, G.711a and GSM.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SIP Network Interface</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enter the name of the network to bind to e.g. eth0</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>NAT Traversal Method</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>NAT IP Address</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>http://checkip.dyndns.org</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If you selected MANUAL above, then enter your Public IP Address here. If you selected WEB Server above then enter your web server URL here.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio RTP Port</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enter the port to use for Audio RTP; an even number between 1024 and 32767. If you have a firewall you should enable UDP through the firewall on this port.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video RTP Port</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enter the port to use for Video RTP; an even number between 1024 and 32767. If you have a firewall you should enable UDP through the firewall on this port.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Auto-Answer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>When the MythFrontend is in the MythPhone plugin, setting this automatically answers all incoming calls. There is no security yet.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SIP Proxy Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>VXML Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>WEBCAM Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Number of webcam frames/sec to transmit, from 1 to 30. Higher numbers create better results but use more bandwidth.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Login to a SIP Server</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SIP Server DNS Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sign-in Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Your username for authentication with the SIP Server. For FWD this is your FWD number.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Your password for authentication with the SIP Server.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Method to use for NAT traversal; needs a Frontend restart after changing. Choose NONE if you have a public IP address, choose MANUAL if your ISP always gives you the same public address and manually enter this address below. Choose Web Server if you have a dynamic NAT address and enter a web address like http://checkip.dyndns.org below. </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Speed Dials</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Voicemail</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Placed Calls</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Received Calls</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>A directory entry already exists with this URL.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Max Transmit Bandwidth Kbps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enter the upspeed bandwidth of your local WAN in Kbps. </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Me</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Jitter Buffer (Audio Call)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Size of the playout buffer in ms for an audio call. </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Jitter Buffer (Video Call)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Size of the playout buffer in ms for a video call. This should be bigger than for an audio call because CPU usage causes jitter and to sync video &amp; audio.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>IP Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>AUDIO Settings</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
